Documentation
¶
Index ¶
- Constants
- Variables
- func FormatUtxo(hash string, index uint32) string
- func GetActionName(ty int32) string
- func InitExecutor(cfg *types.Chain33Config)
- func InitFork(cfg *types.Chain33Config)
- func IsUtxoAddress(addr string) bool
- func NewType(cfg *types.Chain33Config) *rgbxType
- func RegisterRgbxServer(s *grpc.Server, srv RgbxServer)
- type AssetType
- type BtcCommitment
- func (*BtcCommitment) Descriptor() ([]byte, []int)deprecated
- func (x *BtcCommitment) GetAction() uint32
- func (x *BtcCommitment) GetPayload() []byte
- func (x *BtcCommitment) GetProtocol() []byte
- func (*BtcCommitment) ProtoMessage()
- func (x *BtcCommitment) ProtoReflect() protoreflect.Message
- func (x *BtcCommitment) Reset()
- func (x *BtcCommitment) String() string
- type BtcTxProof
- func (*BtcTxProof) Descriptor() ([]byte, []int)deprecated
- func (x *BtcTxProof) GetBlockHash() string
- func (x *BtcTxProof) GetBlockHeight() uint64
- func (x *BtcTxProof) GetMerkleProof() [][]byte
- func (x *BtcTxProof) GetTxData() []byte
- func (x *BtcTxProof) GetTxIndex() uint32
- func (*BtcTxProof) ProtoMessage()
- func (x *BtcTxProof) ProtoReflect() protoreflect.Message
- func (x *BtcTxProof) Reset()
- func (x *BtcTxProof) String() string
- type CommitDKG
- func (*CommitDKG) Descriptor() ([]byte, []int)deprecated
- func (x *CommitDKG) GetAssetSymbol() string
- func (x *CommitDKG) GetDkgAddress() string
- func (x *CommitDKG) GetPkScript() []byte
- func (*CommitDKG) ProtoMessage()
- func (x *CommitDKG) ProtoReflect() protoreflect.Message
- func (x *CommitDKG) Reset()
- func (x *CommitDKG) String() string
- type ConfirmTx
- func (*ConfirmTx) Descriptor() ([]byte, []int)deprecated
- func (x *ConfirmTx) GetActionType() int32
- func (x *ConfirmTx) GetBtcTxProof() *BtcTxProof
- func (x *ConfirmTx) GetConfirmedBlockHeight() int64
- func (x *ConfirmTx) GetTimeout() bool
- func (x *ConfirmTx) GetTxBlockHeight() int64
- func (x *ConfirmTx) GetTxHash() []byte
- func (x *ConfirmTx) GetTxIndex() int64
- func (x *ConfirmTx) GetUtxoProof() *UtxoSpendingProof
- func (*ConfirmTx) ProtoMessage()
- func (x *ConfirmTx) ProtoReflect() protoreflect.Message
- func (x *ConfirmTx) Reset()
- func (x *ConfirmTx) String() string
- type CrossChainInfo
- func (*CrossChainInfo) Descriptor() ([]byte, []int)deprecated
- func (x *CrossChainInfo) GetAssetSymbol() string
- func (x *CrossChainInfo) GetPkScript() []byte
- func (x *CrossChainInfo) GetTssAddress() string
- func (x *CrossChainInfo) GetWrappedSymbol() string
- func (*CrossChainInfo) ProtoMessage()
- func (x *CrossChainInfo) ProtoReflect() protoreflect.Message
- func (x *CrossChainInfo) Reset()
- func (x *CrossChainInfo) String() string
- type DepositAsset
- func (*DepositAsset) Descriptor() ([]byte, []int)deprecated
- func (x *DepositAsset) GetAmount() int64
- func (x *DepositAsset) GetAssetSymbol() string
- func (x *DepositAsset) GetDepositAddress() string
- func (x *DepositAsset) GetTxProof() *BtcTxProof
- func (*DepositAsset) ProtoMessage()
- func (x *DepositAsset) ProtoReflect() protoreflect.Message
- func (x *DepositAsset) Reset()
- func (x *DepositAsset) String() string
- type MintAsset
- func (*MintAsset) Descriptor() ([]byte, []int)deprecated
- func (x *MintAsset) GetGenesisOut() *OutPoint
- func (x *MintAsset) GetMetaHash() []byte
- func (x *MintAsset) GetPrecision() uint32
- func (x *MintAsset) GetSymbol() string
- func (x *MintAsset) GetTotalAmount() int64
- func (x *MintAsset) GetType() uint32
- func (*MintAsset) ProtoMessage()
- func (x *MintAsset) ProtoReflect() protoreflect.Message
- func (x *MintAsset) Reset()
- func (x *MintAsset) String() string
- type OutPoint
- func (*OutPoint) Descriptor() ([]byte, []int)deprecated
- func (o *OutPoint) FromString(s string) error
- func (x *OutPoint) GetHash() string
- func (x *OutPoint) GetIndex() uint32
- func (x *OutPoint) GetPkScript() []byte
- func (*OutPoint) ProtoMessage()
- func (x *OutPoint) ProtoReflect() protoreflect.Message
- func (x *OutPoint) Reset()
- func (x *OutPoint) String() string
- func (o *OutPoint) ToString() string
- type PendingTx
- func (*PendingTx) Descriptor() ([]byte, []int)deprecated
- func (x *PendingTx) GetActionType() int32
- func (x *PendingTx) GetAmount() int64
- func (x *PendingTx) GetAssetSymbol() string
- func (x *PendingTx) GetConfirmed() bool
- func (x *PendingTx) GetFeeRate() int64
- func (x *PendingTx) GetFromAddress() string
- func (x *PendingTx) GetTargetAddress() string
- func (x *PendingTx) GetTimestamp() int64
- func (x *PendingTx) GetTxBlockHeight() int64
- func (x *PendingTx) GetTxHash() []byte
- func (x *PendingTx) GetTxIndex() int64
- func (x *PendingTx) GetUtxo() *OutPoint
- func (*PendingTx) ProtoMessage()
- func (x *PendingTx) ProtoReflect() protoreflect.Message
- func (x *PendingTx) Reset()
- func (x *PendingTx) String() string
- type PendingTxs
- type ReqGetPendingTx
- func (*ReqGetPendingTx) Descriptor() ([]byte, []int)deprecated
- func (x *ReqGetPendingTx) GetHeight() int64
- func (x *ReqGetPendingTx) GetIndex() int64
- func (*ReqGetPendingTx) ProtoMessage()
- func (x *ReqGetPendingTx) ProtoReflect() protoreflect.Message
- func (x *ReqGetPendingTx) Reset()
- func (x *ReqGetPendingTx) String() string
- type ReqListPendingTx
- func (*ReqListPendingTx) Descriptor() ([]byte, []int)deprecated
- func (x *ReqListPendingTx) GetCount() int32
- func (x *ReqListPendingTx) GetEndHeight() int64
- func (x *ReqListPendingTx) GetStartHeight() int64
- func (x *ReqListPendingTx) GetStartIndex() int64
- func (*ReqListPendingTx) ProtoMessage()
- func (x *ReqListPendingTx) ProtoReflect() protoreflect.Message
- func (x *ReqListPendingTx) Reset()
- func (x *ReqListPendingTx) String() string
- type RgbxAction
- func (*RgbxAction) Descriptor() ([]byte, []int)deprecated
- func (x *RgbxAction) GetCommitDKG() *CommitDKG
- func (x *RgbxAction) GetConfirm() *ConfirmTx
- func (x *RgbxAction) GetDeposit() *DepositAsset
- func (x *RgbxAction) GetMint() *MintAsset
- func (x *RgbxAction) GetTransfer() *TransferAsset
- func (x *RgbxAction) GetTy() int32
- func (m *RgbxAction) GetValue() isRgbxAction_Value
- func (x *RgbxAction) GetWithdraw() *WithdrawAsset
- func (*RgbxAction) ProtoMessage()
- func (x *RgbxAction) ProtoReflect() protoreflect.Message
- func (x *RgbxAction) Reset()
- func (x *RgbxAction) String() string
- type RgbxAction_CommitDKG
- type RgbxAction_Confirm
- type RgbxAction_Deposit
- type RgbxAction_Mint
- type RgbxAction_Transfer
- type RgbxAction_Withdraw
- type RgbxAsset
- func (*RgbxAsset) Descriptor() ([]byte, []int)deprecated
- func (x *RgbxAsset) GetGenesisBtcTxHash() string
- func (x *RgbxAsset) GetMetaHash() []byte
- func (x *RgbxAsset) GetOwner() string
- func (x *RgbxAsset) GetPrecision() uint32
- func (x *RgbxAsset) GetSymbol() string
- func (x *RgbxAsset) GetTotalAmount() int64
- func (x *RgbxAsset) GetType() uint32
- func (*RgbxAsset) ProtoMessage()
- func (x *RgbxAsset) ProtoReflect() protoreflect.Message
- func (x *RgbxAsset) Reset()
- func (x *RgbxAsset) String() string
- type RgbxClient
- type RgbxServer
- type TransferAsset
- func (*TransferAsset) Descriptor() ([]byte, []int)deprecated
- func (x *TransferAsset) GetAmount() int64
- func (x *TransferAsset) GetChangeAddr() string
- func (x *TransferAsset) GetFromUtxo() string
- func (x *TransferAsset) GetFromUtxoPkScript() []byte
- func (x *TransferAsset) GetSymbol() string
- func (x *TransferAsset) GetTo() string
- func (*TransferAsset) ProtoMessage()
- func (x *TransferAsset) ProtoReflect() protoreflect.Message
- func (x *TransferAsset) Reset()
- func (x *TransferAsset) String() string
- type TxBlockIndex
- func (*TxBlockIndex) Descriptor() ([]byte, []int)deprecated
- func (x *TxBlockIndex) GetBlockHeight() int64
- func (x *TxBlockIndex) GetTxIndex() int64
- func (*TxBlockIndex) ProtoMessage()
- func (x *TxBlockIndex) ProtoReflect() protoreflect.Message
- func (x *TxBlockIndex) Reset()
- func (x *TxBlockIndex) String() string
- type TxBlockIndexList
- func (*TxBlockIndexList) Descriptor() ([]byte, []int)deprecated
- func (x *TxBlockIndexList) GetBlockIndexList() []*TxBlockIndex
- func (*TxBlockIndexList) ProtoMessage()
- func (x *TxBlockIndexList) ProtoReflect() protoreflect.Message
- func (x *TxBlockIndexList) Reset()
- func (x *TxBlockIndexList) String() string
- type UnimplementedRgbxServer
- type Utxo
- type UtxoSpendingProof
- func (*UtxoSpendingProof) Descriptor() ([]byte, []int)deprecated
- func (x *UtxoSpendingProof) GetOpRetOutputIdx() int32
- func (x *UtxoSpendingProof) GetOpRetOutputPkScript() []byte
- func (x *UtxoSpendingProof) GetSpendingInputIdx() uint32
- func (x *UtxoSpendingProof) GetSpendingTx() []byte
- func (*UtxoSpendingProof) ProtoMessage()
- func (x *UtxoSpendingProof) ProtoReflect() protoreflect.Message
- func (x *UtxoSpendingProof) Reset()
- func (x *UtxoSpendingProof) String() string
- type WithdrawAsset
- func (*WithdrawAsset) Descriptor() ([]byte, []int)deprecated
- func (x *WithdrawAsset) GetAmount() int64
- func (x *WithdrawAsset) GetAssetSymbol() string
- func (x *WithdrawAsset) GetDestinationAddr() string
- func (x *WithdrawAsset) GetFeeRate() int64
- func (*WithdrawAsset) ProtoMessage()
- func (x *WithdrawAsset) ProtoReflect() protoreflect.Message
- func (x *WithdrawAsset) Reset()
- func (x *WithdrawAsset) String() string
Constants ¶
const ( // MaxAssetSymbolLength is the maximum byte length of an asset's symbol. // This byte length is equivalent to character count for single-byte // UTF-8 characters. MaxAssetSymbolLength = 16 // MetaHashLen is the length of the metadata hash. MetaHashLen = 32 // MaxPrecision max Precision MaxPrecision = 8 // MaxAssetAmount max amount MaxAssetAmount = 1e8 * 900 * 1e8 // 900 亿 )
const ( TyUnknownAction = iota + 100 TyMintAction TyTransferAction TyConfirmAction TyCommitDKGAction TyDepositAsset TyWithDrawAsset NameMintAction = "Mint" NameTransferAction = "Transfer" NameConfirmAction = "Confirm" NameCommitDKGAction = "CommitDKG" // 须与 RgbxAction protobuf oneof 字段名一致(chain33 ExecTypeBase.SetChild 用 strings.ToLower 映射), // 例如 oneof deposit -> 此处为 "Deposit",不能为 "DepositAsset"。 NameDepositAssetAction = "Deposit" NameWithdrawAssetAction = "Withdraw" )
action类型id和name,这些常量可以自定义修改
const ( TyUnknownLog = iota + 100 TyAssetLog TyPendingTxLog TyCommitDKGLog TyDepositAssetLog TyWithdrawAssetLog NameAssetLog = "AssetLog" NamePendingTxLog = "PendingTxLog" NameCommitDKGLog = "CommitDKGLog" NameDepositAssetLog = "DepositAssetLog" NameWithdrawAssetLog = "WithdrawAssetLog" )
log类型id值
const (
// BTCSymbol bitcoin
BTCSymbol = "BTC"
)
cross chain asset symbol
Variables ¶
var File_rgbx_proto protoreflect.FileDescriptor
var (
//RgbxX 执行器名称定义
RgbxX = "rgbx"
)
Functions ¶
func FormatUtxo ¶
FormatUtxo format utxo as string
func GetActionName ¶
GetActionName get action name by action type
func InitExecutor ¶
func InitExecutor(cfg *types.Chain33Config)
InitExecutor defines register executor
func NewType ¶
func NewType(cfg *types.Chain33Config) *rgbxType
func RegisterRgbxServer ¶
func RegisterRgbxServer(s *grpc.Server, srv RgbxServer)
Types ¶
type AssetType ¶
type AssetType uint8
AssetType denotes the asset types supported by the Taproot RgbxAsset protocol.
type BtcCommitment ¶
type BtcCommitment struct {
Protocol []byte `protobuf:"bytes,1,opt,name=protocol,proto3" json:"protocol,omitempty"`
Action uint32 `protobuf:"varint,2,opt,name=action,proto3" json:"action,omitempty"`
Payload []byte `protobuf:"bytes,3,opt,name=payload,proto3" json:"payload,omitempty"`
// contains filtered or unexported fields
}
func (*BtcCommitment) Descriptor
deprecated
func (*BtcCommitment) Descriptor() ([]byte, []int)
Deprecated: Use BtcCommitment.ProtoReflect.Descriptor instead.
func (*BtcCommitment) GetAction ¶
func (x *BtcCommitment) GetAction() uint32
func (*BtcCommitment) GetPayload ¶
func (x *BtcCommitment) GetPayload() []byte
func (*BtcCommitment) GetProtocol ¶
func (x *BtcCommitment) GetProtocol() []byte
func (*BtcCommitment) ProtoMessage ¶
func (*BtcCommitment) ProtoMessage()
func (*BtcCommitment) ProtoReflect ¶
func (x *BtcCommitment) ProtoReflect() protoreflect.Message
func (*BtcCommitment) Reset ¶
func (x *BtcCommitment) Reset()
func (*BtcCommitment) String ¶
func (x *BtcCommitment) String() string
type BtcTxProof ¶
type BtcTxProof struct {
BlockHeight uint64 `protobuf:"varint,1,opt,name=blockHeight,proto3" json:"blockHeight,omitempty"`
TxIndex uint32 `protobuf:"varint,2,opt,name=txIndex,proto3" json:"txIndex,omitempty"`
BlockHash string `protobuf:"bytes,3,opt,name=blockHash,proto3" json:"blockHash,omitempty"`
TxData []byte `protobuf:"bytes,4,opt,name=txData,proto3" json:"txData,omitempty"`
MerkleProof [][]byte `protobuf:"bytes,5,rep,name=merkleProof,proto3" json:"merkleProof,omitempty"`
// contains filtered or unexported fields
}
func (*BtcTxProof) Descriptor
deprecated
func (*BtcTxProof) Descriptor() ([]byte, []int)
Deprecated: Use BtcTxProof.ProtoReflect.Descriptor instead.
func (*BtcTxProof) GetBlockHash ¶
func (x *BtcTxProof) GetBlockHash() string
func (*BtcTxProof) GetBlockHeight ¶
func (x *BtcTxProof) GetBlockHeight() uint64
func (*BtcTxProof) GetMerkleProof ¶
func (x *BtcTxProof) GetMerkleProof() [][]byte
func (*BtcTxProof) GetTxData ¶
func (x *BtcTxProof) GetTxData() []byte
func (*BtcTxProof) GetTxIndex ¶
func (x *BtcTxProof) GetTxIndex() uint32
func (*BtcTxProof) ProtoMessage ¶
func (*BtcTxProof) ProtoMessage()
func (*BtcTxProof) ProtoReflect ¶
func (x *BtcTxProof) ProtoReflect() protoreflect.Message
func (*BtcTxProof) Reset ¶
func (x *BtcTxProof) Reset()
func (*BtcTxProof) String ¶
func (x *BtcTxProof) String() string
type CommitDKG ¶
type CommitDKG struct {
AssetSymbol string `protobuf:"bytes,1,opt,name=assetSymbol,proto3" json:"assetSymbol,omitempty"`
DkgAddress string `protobuf:"bytes,2,opt,name=dkgAddress,proto3" json:"dkgAddress,omitempty"`
PkScript []byte `protobuf:"bytes,3,opt,name=pkScript,proto3" json:"pkScript,omitempty"`
// contains filtered or unexported fields
}
func (*CommitDKG) Descriptor
deprecated
func (*CommitDKG) GetAssetSymbol ¶
func (*CommitDKG) GetDkgAddress ¶
func (*CommitDKG) GetPkScript ¶
func (*CommitDKG) ProtoMessage ¶
func (*CommitDKG) ProtoMessage()
func (*CommitDKG) ProtoReflect ¶
func (x *CommitDKG) ProtoReflect() protoreflect.Message
type ConfirmTx ¶
type ConfirmTx struct {
ActionType int32 `protobuf:"varint,1,opt,name=actionType,proto3" json:"actionType,omitempty"`
ConfirmedBlockHeight int64 `protobuf:"varint,2,opt,name=confirmedBlockHeight,proto3" json:"confirmedBlockHeight,omitempty"`
TxBlockHeight int64 `protobuf:"varint,3,opt,name=txBlockHeight,proto3" json:"txBlockHeight,omitempty"`
TxIndex int64 `protobuf:"varint,4,opt,name=txIndex,proto3" json:"txIndex,omitempty"`
TxHash []byte `protobuf:"bytes,5,opt,name=txHash,proto3" json:"txHash,omitempty"`
Timeout bool `protobuf:"varint,6,opt,name=timeout,proto3" json:"timeout,omitempty"`
UtxoProof *UtxoSpendingProof `protobuf:"bytes,7,opt,name=utxoProof,proto3" json:"utxoProof,omitempty"`
BtcTxProof *BtcTxProof `protobuf:"bytes,8,opt,name=btcTxProof,proto3" json:"btcTxProof,omitempty"`
// contains filtered or unexported fields
}
func (*ConfirmTx) Descriptor
deprecated
func (*ConfirmTx) GetActionType ¶
func (*ConfirmTx) GetBtcTxProof ¶
func (x *ConfirmTx) GetBtcTxProof() *BtcTxProof
func (*ConfirmTx) GetConfirmedBlockHeight ¶
func (*ConfirmTx) GetTimeout ¶
func (*ConfirmTx) GetTxBlockHeight ¶
func (*ConfirmTx) GetTxIndex ¶
func (*ConfirmTx) GetUtxoProof ¶
func (x *ConfirmTx) GetUtxoProof() *UtxoSpendingProof
func (*ConfirmTx) ProtoMessage ¶
func (*ConfirmTx) ProtoMessage()
func (*ConfirmTx) ProtoReflect ¶
func (x *ConfirmTx) ProtoReflect() protoreflect.Message
type CrossChainInfo ¶
type CrossChainInfo struct {
AssetSymbol string `protobuf:"bytes,1,opt,name=assetSymbol,proto3" json:"assetSymbol,omitempty"`
WrappedSymbol string `protobuf:"bytes,2,opt,name=wrappedSymbol,proto3" json:"wrappedSymbol,omitempty"`
TssAddress string `protobuf:"bytes,3,opt,name=tssAddress,proto3" json:"tssAddress,omitempty"`
PkScript []byte `protobuf:"bytes,4,opt,name=pkScript,proto3" json:"pkScript,omitempty"`
// contains filtered or unexported fields
}
func (*CrossChainInfo) Descriptor
deprecated
func (*CrossChainInfo) Descriptor() ([]byte, []int)
Deprecated: Use CrossChainInfo.ProtoReflect.Descriptor instead.
func (*CrossChainInfo) GetAssetSymbol ¶
func (x *CrossChainInfo) GetAssetSymbol() string
func (*CrossChainInfo) GetPkScript ¶
func (x *CrossChainInfo) GetPkScript() []byte
func (*CrossChainInfo) GetTssAddress ¶
func (x *CrossChainInfo) GetTssAddress() string
func (*CrossChainInfo) GetWrappedSymbol ¶
func (x *CrossChainInfo) GetWrappedSymbol() string
func (*CrossChainInfo) ProtoMessage ¶
func (*CrossChainInfo) ProtoMessage()
func (*CrossChainInfo) ProtoReflect ¶
func (x *CrossChainInfo) ProtoReflect() protoreflect.Message
func (*CrossChainInfo) Reset ¶
func (x *CrossChainInfo) Reset()
func (*CrossChainInfo) String ¶
func (x *CrossChainInfo) String() string
type DepositAsset ¶
type DepositAsset struct {
Amount int64 `protobuf:"varint,1,opt,name=amount,proto3" json:"amount,omitempty"`
DepositAddress string `protobuf:"bytes,2,opt,name=depositAddress,proto3" json:"depositAddress,omitempty"`
AssetSymbol string `protobuf:"bytes,3,opt,name=assetSymbol,proto3" json:"assetSymbol,omitempty"`
TxProof *BtcTxProof `protobuf:"bytes,4,opt,name=txProof,proto3" json:"txProof,omitempty"`
// contains filtered or unexported fields
}
func (*DepositAsset) Descriptor
deprecated
func (*DepositAsset) Descriptor() ([]byte, []int)
Deprecated: Use DepositAsset.ProtoReflect.Descriptor instead.
func (*DepositAsset) GetAmount ¶
func (x *DepositAsset) GetAmount() int64
func (*DepositAsset) GetAssetSymbol ¶
func (x *DepositAsset) GetAssetSymbol() string
func (*DepositAsset) GetDepositAddress ¶
func (x *DepositAsset) GetDepositAddress() string
func (*DepositAsset) GetTxProof ¶
func (x *DepositAsset) GetTxProof() *BtcTxProof
func (*DepositAsset) ProtoMessage ¶
func (*DepositAsset) ProtoMessage()
func (*DepositAsset) ProtoReflect ¶
func (x *DepositAsset) ProtoReflect() protoreflect.Message
func (*DepositAsset) Reset ¶
func (x *DepositAsset) Reset()
func (*DepositAsset) String ¶
func (x *DepositAsset) String() string
type MintAsset ¶
type MintAsset struct {
Type uint32 `protobuf:"varint,1,opt,name=type,proto3" json:"type,omitempty"`
Precision uint32 `protobuf:"varint,2,opt,name=precision,proto3" json:"precision,omitempty"`
TotalAmount int64 `protobuf:"varint,3,opt,name=totalAmount,proto3" json:"totalAmount,omitempty"`
Symbol string `protobuf:"bytes,4,opt,name=symbol,proto3" json:"symbol,omitempty"`
MetaHash []byte `protobuf:"bytes,5,opt,name=metaHash,proto3" json:"metaHash,omitempty"`
// represents the outpoint of the transaction's
// input that resulted in the creation of the asset.
GenesisOut *OutPoint `protobuf:"bytes,6,opt,name=genesisOut,proto3" json:"genesisOut,omitempty"`
// contains filtered or unexported fields
}
func (*MintAsset) Descriptor
deprecated
func (*MintAsset) GetGenesisOut ¶
func (*MintAsset) GetMetaHash ¶
func (*MintAsset) GetPrecision ¶
func (*MintAsset) GetTotalAmount ¶
func (*MintAsset) ProtoMessage ¶
func (*MintAsset) ProtoMessage()
func (*MintAsset) ProtoReflect ¶
func (x *MintAsset) ProtoReflect() protoreflect.Message
type OutPoint ¶
type OutPoint struct {
Hash string `protobuf:"bytes,1,opt,name=hash,proto3" json:"hash,omitempty"`
Index uint32 `protobuf:"varint,2,opt,name=index,proto3" json:"index,omitempty"`
PkScript []byte `protobuf:"bytes,3,opt,name=pkScript,proto3" json:"pkScript,omitempty"`
// contains filtered or unexported fields
}
func NewOutPointFromString ¶
NewOutPointFromString new out point
func (*OutPoint) Descriptor
deprecated
func (*OutPoint) FromString ¶
FromString decode from string
func (*OutPoint) GetPkScript ¶
func (*OutPoint) ProtoMessage ¶
func (*OutPoint) ProtoMessage()
func (*OutPoint) ProtoReflect ¶
func (x *OutPoint) ProtoReflect() protoreflect.Message
type PendingTx ¶
type PendingTx struct {
ActionType int32 `protobuf:"varint,1,opt,name=actionType,proto3" json:"actionType,omitempty"`
Timestamp int64 `protobuf:"varint,2,opt,name=timestamp,proto3" json:"timestamp,omitempty"`
TxBlockHeight int64 `protobuf:"varint,3,opt,name=txBlockHeight,proto3" json:"txBlockHeight,omitempty"`
TxIndex int64 `protobuf:"varint,4,opt,name=txIndex,proto3" json:"txIndex,omitempty"`
Amount int64 `protobuf:"varint,5,opt,name=amount,proto3" json:"amount,omitempty"`
FeeRate int64 `protobuf:"varint,6,opt,name=feeRate,proto3" json:"feeRate,omitempty"`
TxHash []byte `protobuf:"bytes,7,opt,name=txHash,proto3" json:"txHash,omitempty"`
Utxo *OutPoint `protobuf:"bytes,8,opt,name=utxo,proto3" json:"utxo,omitempty"`
FromAddress string `protobuf:"bytes,9,opt,name=fromAddress,proto3" json:"fromAddress,omitempty"`
AssetSymbol string `protobuf:"bytes,10,opt,name=assetSymbol,proto3" json:"assetSymbol,omitempty"`
TargetAddress string `protobuf:"bytes,11,opt,name=targetAddress,proto3" json:"targetAddress,omitempty"`
Confirmed bool `protobuf:"varint,12,opt,name=confirmed,proto3" json:"confirmed,omitempty"`
// contains filtered or unexported fields
}
func (*PendingTx) Descriptor
deprecated
func (*PendingTx) GetActionType ¶
func (*PendingTx) GetAssetSymbol ¶
func (*PendingTx) GetConfirmed ¶
func (*PendingTx) GetFeeRate ¶
func (*PendingTx) GetFromAddress ¶
func (*PendingTx) GetTargetAddress ¶
func (*PendingTx) GetTimestamp ¶
func (*PendingTx) GetTxBlockHeight ¶
func (*PendingTx) GetTxIndex ¶
func (*PendingTx) ProtoMessage ¶
func (*PendingTx) ProtoMessage()
func (*PendingTx) ProtoReflect ¶
func (x *PendingTx) ProtoReflect() protoreflect.Message
type PendingTxs ¶
type PendingTxs struct {
PendingList []*PendingTx `protobuf:"bytes,1,rep,name=pendingList,proto3" json:"pendingList,omitempty"`
// contains filtered or unexported fields
}
func (*PendingTxs) Descriptor
deprecated
func (*PendingTxs) Descriptor() ([]byte, []int)
Deprecated: Use PendingTxs.ProtoReflect.Descriptor instead.
func (*PendingTxs) GetPendingList ¶
func (x *PendingTxs) GetPendingList() []*PendingTx
func (*PendingTxs) ProtoMessage ¶
func (*PendingTxs) ProtoMessage()
func (*PendingTxs) ProtoReflect ¶
func (x *PendingTxs) ProtoReflect() protoreflect.Message
func (*PendingTxs) Reset ¶
func (x *PendingTxs) Reset()
func (*PendingTxs) String ¶
func (x *PendingTxs) String() string
type ReqGetPendingTx ¶
type ReqGetPendingTx struct {
Height int64 `protobuf:"varint,1,opt,name=height,proto3" json:"height,omitempty"`
Index int64 `protobuf:"varint,2,opt,name=index,proto3" json:"index,omitempty"`
// contains filtered or unexported fields
}
func (*ReqGetPendingTx) Descriptor
deprecated
func (*ReqGetPendingTx) Descriptor() ([]byte, []int)
Deprecated: Use ReqGetPendingTx.ProtoReflect.Descriptor instead.
func (*ReqGetPendingTx) GetHeight ¶
func (x *ReqGetPendingTx) GetHeight() int64
func (*ReqGetPendingTx) GetIndex ¶
func (x *ReqGetPendingTx) GetIndex() int64
func (*ReqGetPendingTx) ProtoMessage ¶
func (*ReqGetPendingTx) ProtoMessage()
func (*ReqGetPendingTx) ProtoReflect ¶
func (x *ReqGetPendingTx) ProtoReflect() protoreflect.Message
func (*ReqGetPendingTx) Reset ¶
func (x *ReqGetPendingTx) Reset()
func (*ReqGetPendingTx) String ¶
func (x *ReqGetPendingTx) String() string
type ReqListPendingTx ¶
type ReqListPendingTx struct {
StartHeight int64 `protobuf:"varint,1,opt,name=startHeight,proto3" json:"startHeight,omitempty"`
StartIndex int64 `protobuf:"varint,2,opt,name=startIndex,proto3" json:"startIndex,omitempty"`
Count int32 `protobuf:"varint,3,opt,name=count,proto3" json:"count,omitempty"`
EndHeight int64 `protobuf:"varint,4,opt,name=endHeight,proto3" json:"endHeight,omitempty"`
// contains filtered or unexported fields
}
func (*ReqListPendingTx) Descriptor
deprecated
func (*ReqListPendingTx) Descriptor() ([]byte, []int)
Deprecated: Use ReqListPendingTx.ProtoReflect.Descriptor instead.
func (*ReqListPendingTx) GetCount ¶
func (x *ReqListPendingTx) GetCount() int32
func (*ReqListPendingTx) GetEndHeight ¶
func (x *ReqListPendingTx) GetEndHeight() int64
func (*ReqListPendingTx) GetStartHeight ¶
func (x *ReqListPendingTx) GetStartHeight() int64
func (*ReqListPendingTx) GetStartIndex ¶
func (x *ReqListPendingTx) GetStartIndex() int64
func (*ReqListPendingTx) ProtoMessage ¶
func (*ReqListPendingTx) ProtoMessage()
func (*ReqListPendingTx) ProtoReflect ¶
func (x *ReqListPendingTx) ProtoReflect() protoreflect.Message
func (*ReqListPendingTx) Reset ¶
func (x *ReqListPendingTx) Reset()
func (*ReqListPendingTx) String ¶
func (x *ReqListPendingTx) String() string
type RgbxAction ¶
type RgbxAction struct {
Ty int32 `protobuf:"varint,1,opt,name=ty,proto3" json:"ty,omitempty"`
// Types that are assignable to Value:
// *RgbxAction_Mint
// *RgbxAction_Transfer
// *RgbxAction_Confirm
// *RgbxAction_CommitDKG
// *RgbxAction_Deposit
// *RgbxAction_Withdraw
Value isRgbxAction_Value `protobuf_oneof:"value"`
// contains filtered or unexported fields
}
func (*RgbxAction) Descriptor
deprecated
func (*RgbxAction) Descriptor() ([]byte, []int)
Deprecated: Use RgbxAction.ProtoReflect.Descriptor instead.
func (*RgbxAction) GetCommitDKG ¶
func (x *RgbxAction) GetCommitDKG() *CommitDKG
func (*RgbxAction) GetConfirm ¶
func (x *RgbxAction) GetConfirm() *ConfirmTx
func (*RgbxAction) GetDeposit ¶
func (x *RgbxAction) GetDeposit() *DepositAsset
func (*RgbxAction) GetMint ¶
func (x *RgbxAction) GetMint() *MintAsset
func (*RgbxAction) GetTransfer ¶
func (x *RgbxAction) GetTransfer() *TransferAsset
func (*RgbxAction) GetTy ¶
func (x *RgbxAction) GetTy() int32
func (*RgbxAction) GetValue ¶
func (m *RgbxAction) GetValue() isRgbxAction_Value
func (*RgbxAction) GetWithdraw ¶
func (x *RgbxAction) GetWithdraw() *WithdrawAsset
func (*RgbxAction) ProtoMessage ¶
func (*RgbxAction) ProtoMessage()
func (*RgbxAction) ProtoReflect ¶
func (x *RgbxAction) ProtoReflect() protoreflect.Message
func (*RgbxAction) Reset ¶
func (x *RgbxAction) Reset()
func (*RgbxAction) String ¶
func (x *RgbxAction) String() string
type RgbxAction_CommitDKG ¶
type RgbxAction_CommitDKG struct {
CommitDKG *CommitDKG `protobuf:"bytes,5,opt,name=commitDKG,proto3,oneof"`
}
type RgbxAction_Confirm ¶
type RgbxAction_Confirm struct {
Confirm *ConfirmTx `protobuf:"bytes,4,opt,name=confirm,proto3,oneof"`
}
type RgbxAction_Deposit ¶
type RgbxAction_Deposit struct {
Deposit *DepositAsset `protobuf:"bytes,6,opt,name=deposit,proto3,oneof"`
}
type RgbxAction_Mint ¶
type RgbxAction_Mint struct {
Mint *MintAsset `protobuf:"bytes,2,opt,name=mint,proto3,oneof"`
}
type RgbxAction_Transfer ¶
type RgbxAction_Transfer struct {
Transfer *TransferAsset `protobuf:"bytes,3,opt,name=transfer,proto3,oneof"`
}
type RgbxAction_Withdraw ¶
type RgbxAction_Withdraw struct {
Withdraw *WithdrawAsset `protobuf:"bytes,7,opt,name=withdraw,proto3,oneof"`
}
type RgbxAsset ¶
type RgbxAsset struct {
Type uint32 `protobuf:"varint,1,opt,name=type,proto3" json:"type,omitempty"`
Precision uint32 `protobuf:"varint,2,opt,name=precision,proto3" json:"precision,omitempty"`
TotalAmount int64 `protobuf:"varint,3,opt,name=totalAmount,proto3" json:"totalAmount,omitempty"`
Symbol string `protobuf:"bytes,4,opt,name=symbol,proto3" json:"symbol,omitempty"`
MetaHash []byte `protobuf:"bytes,5,opt,name=metaHash,proto3" json:"metaHash,omitempty"`
GenesisBtcTxHash string `protobuf:"bytes,6,opt,name=genesisBtcTxHash,proto3" json:"genesisBtcTxHash,omitempty"`
Owner string `protobuf:"bytes,7,opt,name=owner,proto3" json:"owner,omitempty"`
// contains filtered or unexported fields
}
func (*RgbxAsset) Descriptor
deprecated
func (*RgbxAsset) GetGenesisBtcTxHash ¶
func (*RgbxAsset) GetMetaHash ¶
func (*RgbxAsset) GetPrecision ¶
func (*RgbxAsset) GetTotalAmount ¶
func (*RgbxAsset) ProtoMessage ¶
func (*RgbxAsset) ProtoMessage()
func (*RgbxAsset) ProtoReflect ¶
func (x *RgbxAsset) ProtoReflect() protoreflect.Message
type RgbxClient ¶
type RgbxClient interface {
}
RgbxClient is the client API for Rgbx service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewRgbxClient ¶
func NewRgbxClient(cc grpc.ClientConnInterface) RgbxClient
type TransferAsset ¶
type TransferAsset struct {
Symbol string `protobuf:"bytes,1,opt,name=symbol,proto3" json:"symbol,omitempty"`
Amount int64 `protobuf:"varint,2,opt,name=amount,proto3" json:"amount,omitempty"`
FromUtxo string `protobuf:"bytes,3,opt,name=fromUtxo,proto3" json:"fromUtxo,omitempty"`
To string `protobuf:"bytes,4,opt,name=to,proto3" json:"to,omitempty"`
ChangeAddr string `protobuf:"bytes,5,opt,name=changeAddr,proto3" json:"changeAddr,omitempty"`
FromUtxoPkScript []byte `protobuf:"bytes,6,opt,name=fromUtxoPkScript,proto3" json:"fromUtxoPkScript,omitempty"`
// contains filtered or unexported fields
}
func (*TransferAsset) Descriptor
deprecated
func (*TransferAsset) Descriptor() ([]byte, []int)
Deprecated: Use TransferAsset.ProtoReflect.Descriptor instead.
func (*TransferAsset) GetAmount ¶
func (x *TransferAsset) GetAmount() int64
func (*TransferAsset) GetChangeAddr ¶
func (x *TransferAsset) GetChangeAddr() string
func (*TransferAsset) GetFromUtxo ¶
func (x *TransferAsset) GetFromUtxo() string
func (*TransferAsset) GetFromUtxoPkScript ¶
func (x *TransferAsset) GetFromUtxoPkScript() []byte
func (*TransferAsset) GetSymbol ¶
func (x *TransferAsset) GetSymbol() string
func (*TransferAsset) GetTo ¶
func (x *TransferAsset) GetTo() string
func (*TransferAsset) ProtoMessage ¶
func (*TransferAsset) ProtoMessage()
func (*TransferAsset) ProtoReflect ¶
func (x *TransferAsset) ProtoReflect() protoreflect.Message
func (*TransferAsset) Reset ¶
func (x *TransferAsset) Reset()
func (*TransferAsset) String ¶
func (x *TransferAsset) String() string
type TxBlockIndex ¶
type TxBlockIndex struct {
BlockHeight int64 `protobuf:"varint,1,opt,name=blockHeight,proto3" json:"blockHeight,omitempty"`
TxIndex int64 `protobuf:"varint,2,opt,name=txIndex,proto3" json:"txIndex,omitempty"`
// contains filtered or unexported fields
}
func (*TxBlockIndex) Descriptor
deprecated
func (*TxBlockIndex) Descriptor() ([]byte, []int)
Deprecated: Use TxBlockIndex.ProtoReflect.Descriptor instead.
func (*TxBlockIndex) GetBlockHeight ¶
func (x *TxBlockIndex) GetBlockHeight() int64
func (*TxBlockIndex) GetTxIndex ¶
func (x *TxBlockIndex) GetTxIndex() int64
func (*TxBlockIndex) ProtoMessage ¶
func (*TxBlockIndex) ProtoMessage()
func (*TxBlockIndex) ProtoReflect ¶
func (x *TxBlockIndex) ProtoReflect() protoreflect.Message
func (*TxBlockIndex) Reset ¶
func (x *TxBlockIndex) Reset()
func (*TxBlockIndex) String ¶
func (x *TxBlockIndex) String() string
type TxBlockIndexList ¶
type TxBlockIndexList struct {
BlockIndexList []*TxBlockIndex `protobuf:"bytes,1,rep,name=blockIndexList,proto3" json:"blockIndexList,omitempty"`
// contains filtered or unexported fields
}
func (*TxBlockIndexList) Descriptor
deprecated
func (*TxBlockIndexList) Descriptor() ([]byte, []int)
Deprecated: Use TxBlockIndexList.ProtoReflect.Descriptor instead.
func (*TxBlockIndexList) GetBlockIndexList ¶
func (x *TxBlockIndexList) GetBlockIndexList() []*TxBlockIndex
func (*TxBlockIndexList) ProtoMessage ¶
func (*TxBlockIndexList) ProtoMessage()
func (*TxBlockIndexList) ProtoReflect ¶
func (x *TxBlockIndexList) ProtoReflect() protoreflect.Message
func (*TxBlockIndexList) Reset ¶
func (x *TxBlockIndexList) Reset()
func (*TxBlockIndexList) String ¶
func (x *TxBlockIndexList) String() string
type UnimplementedRgbxServer ¶
type UnimplementedRgbxServer struct {
}
UnimplementedRgbxServer can be embedded to have forward compatible implementations.
type Utxo ¶
type Utxo struct {
OutPoint string `protobuf:"bytes,1,opt,name=outPoint,proto3" json:"outPoint,omitempty"`
Amount int64 `protobuf:"varint,2,opt,name=amount,proto3" json:"amount,omitempty"`
PkScript []byte `protobuf:"bytes,3,opt,name=pkScript,proto3" json:"pkScript,omitempty"`
// contains filtered or unexported fields
}
func (*Utxo) Descriptor
deprecated
func (*Utxo) GetOutPoint ¶
func (*Utxo) GetPkScript ¶
func (*Utxo) ProtoMessage ¶
func (*Utxo) ProtoMessage()
func (*Utxo) ProtoReflect ¶
func (x *Utxo) ProtoReflect() protoreflect.Message
type UtxoSpendingProof ¶
type UtxoSpendingProof struct {
SpendingInputIdx uint32 `protobuf:"varint,1,opt,name=spendingInputIdx,proto3" json:"spendingInputIdx,omitempty"`
OpRetOutputIdx int32 `protobuf:"varint,2,opt,name=opRetOutputIdx,proto3" json:"opRetOutputIdx,omitempty"`
SpendingTx []byte `protobuf:"bytes,3,opt,name=spendingTx,proto3" json:"spendingTx,omitempty"`
OpRetOutputPkScript []byte `protobuf:"bytes,4,opt,name=opRetOutputPkScript,proto3" json:"opRetOutputPkScript,omitempty"`
// contains filtered or unexported fields
}
func (*UtxoSpendingProof) Descriptor
deprecated
func (*UtxoSpendingProof) Descriptor() ([]byte, []int)
Deprecated: Use UtxoSpendingProof.ProtoReflect.Descriptor instead.
func (*UtxoSpendingProof) GetOpRetOutputIdx ¶
func (x *UtxoSpendingProof) GetOpRetOutputIdx() int32
func (*UtxoSpendingProof) GetOpRetOutputPkScript ¶
func (x *UtxoSpendingProof) GetOpRetOutputPkScript() []byte
func (*UtxoSpendingProof) GetSpendingInputIdx ¶
func (x *UtxoSpendingProof) GetSpendingInputIdx() uint32
func (*UtxoSpendingProof) GetSpendingTx ¶
func (x *UtxoSpendingProof) GetSpendingTx() []byte
func (*UtxoSpendingProof) ProtoMessage ¶
func (*UtxoSpendingProof) ProtoMessage()
func (*UtxoSpendingProof) ProtoReflect ¶
func (x *UtxoSpendingProof) ProtoReflect() protoreflect.Message
func (*UtxoSpendingProof) Reset ¶
func (x *UtxoSpendingProof) Reset()
func (*UtxoSpendingProof) String ¶
func (x *UtxoSpendingProof) String() string
type WithdrawAsset ¶
type WithdrawAsset struct {
Amount int64 `protobuf:"varint,1,opt,name=amount,proto3" json:"amount,omitempty"`
FeeRate int64 `protobuf:"varint,2,opt,name=feeRate,proto3" json:"feeRate,omitempty"`
DestinationAddr string `protobuf:"bytes,3,opt,name=destinationAddr,proto3" json:"destinationAddr,omitempty"`
AssetSymbol string `protobuf:"bytes,4,opt,name=assetSymbol,proto3" json:"assetSymbol,omitempty"`
// contains filtered or unexported fields
}
func (*WithdrawAsset) Descriptor
deprecated
func (*WithdrawAsset) Descriptor() ([]byte, []int)
Deprecated: Use WithdrawAsset.ProtoReflect.Descriptor instead.
func (*WithdrawAsset) GetAmount ¶
func (x *WithdrawAsset) GetAmount() int64
func (*WithdrawAsset) GetAssetSymbol ¶
func (x *WithdrawAsset) GetAssetSymbol() string
func (*WithdrawAsset) GetDestinationAddr ¶
func (x *WithdrawAsset) GetDestinationAddr() string
func (*WithdrawAsset) GetFeeRate ¶
func (x *WithdrawAsset) GetFeeRate() int64
func (*WithdrawAsset) ProtoMessage ¶
func (*WithdrawAsset) ProtoMessage()
func (*WithdrawAsset) ProtoReflect ¶
func (x *WithdrawAsset) ProtoReflect() protoreflect.Message
func (*WithdrawAsset) Reset ¶
func (x *WithdrawAsset) Reset()
func (*WithdrawAsset) String ¶
func (x *WithdrawAsset) String() string